.. _strategies-index:

Strategies index
================

Here are the docstrings of all the strategies in the library.


.. automodule:: axelrod.strategies.adaptive
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.alternator
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.ann
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.apavlov
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.appeaser
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.averagecopier
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.axelrod_first
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.axelrod_second
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.backstabber
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.better_and_better
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.bush_mosteller
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.calculator
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.cooperator
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.cycler
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.darwin
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.dbs
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.defector
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.doubler
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.finite_state_machines
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.forgiver
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.gambler
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.geller
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.gobymajority
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.gradualkiller
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.grudger
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.grumpy
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.handshake
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.hmm
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.hunter
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.inverse
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.lookerup
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.mathematicalconstants
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.memorytwo
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.memoryone
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.meta
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.mindcontrol
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.mindreader
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.mutual
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.negation
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.oncebitten
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.prober
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.punisher
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.qlearner
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.rand
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.resurrection
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.retaliate
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.sequence_player
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.shortmem
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.selfsteem
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.stalker
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.titfortat
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.verybad
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.worse_and_worse
   :members:
   :undoc-members:
.. automodule:: axelrod.strategies.zero_determinant
   :members:
   :undoc-members:
